@@ -1,5 +1,5 @@
 package Limper;
-$Limper::VERSION = '0.012';
+$Limper::VERSION = '0.013';
 use 5.10.0;
 use strict;
 use warnings;
@@ -122,6 +122,8 @@ sub get_request {
             next if $line eq "\r\n";
             ($request->{method}, $request->{uri}, $request->{version}) = $line =~ /^($method_rx) ($uri_rx) ($version_rx)\r\n/;
             return bad_request $line unless defined $request->{method};
+            ($request->{scheme}, $request->{authority}, $request->{path}, $request->{query}, $request->{fragment}) =
+                    $request->{uri} =~ m|(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*)(?:\?([^#]*))?(?:#(.*))?|;	# from https://metacpan.org/pod/URI
             $request_line = 1;
         } elsif (!defined $headers_done) {
             if ($line =~ /^\r\n/) {
@@ -177,8 +179,8 @@ sub handle_request {
     (defined $request->{method} and $request->{method} eq 'HEAD') ? ($request->{method} = 'GET') : ($head = 0);
     if (defined $request->{method} and exists $route->{$request->{method}}) {
         for (my $i = 0; $i < @{$route->{$request->{method}}}; $i += 2) {
-            if ($route->{$request->{method}}[$i] eq $request->{uri} ||
-                        ref $route->{$request->{method}}[$i] eq 'Regexp' and $request->{uri} =~ $route->{$request->{method}}[$i]) {
+            if ($route->{$request->{method}}[$i] eq $request->{path} ||
+                        ref $route->{$request->{method}}[$i] eq 'Regexp' and $request->{path} =~ $route->{$request->{method}}[$i]) {
                 $response->{body} = & { $route->{$request->{method}}[$i+1] };
                 return send_response($head);
             }
@@ -297,7 +299,7 @@ Limper - extremely lightweight but not very powerful web application framework
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -314,6 +316,10 @@ version 0.012
       'you posted something: ' . request->{body};
   };
 
+  get '/baz' => sub {
+      'your non-decoded query, if any: ' . request->{query};	# URIs of '/baz?fizz=buzz&foo=bar' now work
+  };
+
   limp;
 
 =head1 DESCRIPTION
@@ -407,9 +413,11 @@ previously defined headers.
 =head2 request
 
 Returns a B<HASH> of the request. Request keys are: B<method>, B<uri>, and
-B<version>.  It may also contain B<headers> which is a B<HASH> and B<body>.
+B<version>.  B<uri> is now broken down and there are additional keys:
+B<scheme>, B<authority>, B<path>, B<query>, and B<fragment>.  It may also
+contain B<headers> which is a B<HASH> and B<body>.
 
-There is no decoding of the body content nor URL paramters.
+There is no decoding of the body content nor URL parameters.
 
 =head2 response
 
